@@ -1,19 +1,39 @@
 # emacs: -*- mode: python; py-indent-offset: 4; indent-tabs-mode: nil -*-
 # vi: set ft=python sts=4 ts=4 sw=4 et:
+#
+# Copyright 2021 The NiPreps Developers <nipreps@gmail.com>
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#     http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+#
+# We support and encourage derived works from this project, please read
+# about our expectations at
+#
+#     https://www.nipreps.org/community/licensing/
+#
 """Reports."""
-import numpy as np
 import nibabel as nb
+import numpy as np
+from mriqc import config
+from mriqc.reports.individual import individual_html
 from nipype.interfaces.base import (
-    traits,
-    TraitedSpec,
-    File,
-    isdefined,
-    InputMultiObject,
     BaseInterfaceInputSpec,
+    File,
+    InputMultiObject,
     SimpleInterface,
+    TraitedSpec,
+    isdefined,
+    traits,
 )
-from .. import config
-from ..reports.individual import individual_html
 
 
 class _IndividualReportInputSpec(BaseInterfaceInputSpec):
@@ -67,7 +87,9 @@ class AddProvenance(SimpleInterface):
             "software": "mriqc",
             "webapi_url": config.execution.webapi_url,
             "webapi_port": config.execution.webapi_port,
-            "settings": {"testing": config.execution.debug, },
+            "settings": {
+                "testing": config.execution.debug,
+            },
         }
 
         if self.inputs.modality in ("T1w", "T2w"):
